@@ -6,18 +6,17 @@ use Log::Message::Simple qw[msg error debug];
 
 no warnings qw/redefine/;
 
-
 =head1 NAME
 
 WebService::UMLSKS::Similarity - access the Unified Medical Language System (UMLS) via Webservices
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 SYNOPSIS
 
@@ -70,36 +69,34 @@ parameters.
 =cut
 
 sub new {
-	
 
 	my $class  = shift;
 	my $params = shift;
-	
-	
+
 	my @s_array = ("SNOMEDCT");
 	my @r_array = ("PAR");
 	my @d_array = ("U");
 	my @a_array = ();
-	
-	my  %ConfigurationParameters = ("SAB" ,\@s_array,"REL",\@r_array,"DIR",\@d_array,"RELA",\@a_array);
-	my $self   = \%ConfigurationParameters; 
-	
-	
-	bless(  $self ,$class);
-	
-	# call initialiseParameters only if parameters are passed else use default values
-	if (defined $params && $params ne "")
-	{
-	$self->initialiseParameters($params);
-	#printhashvaluearray(\%ConfigurationParameters);
-	
+
+	my %ConfigurationParameters = (
+		"SAB", \@s_array, "REL",  \@r_array,
+		"DIR", \@d_array, "RELA", \@a_array
+	);
+	my $self = \%ConfigurationParameters;
+
+	bless( $self, $class );
+
+# call initialiseParameters only if parameters are passed else use default values
+	if ( defined $params && $params ne "" ) {
+		$self->initialiseParameters($params);
+
+		#printhashvaluearray(\%ConfigurationParameters);
+
 	}
-	
-	
+
 	return $self;
 }
 
-
 =head2 initialiseParameters
 
 This subroutine sets the configuaration parameters hash 
@@ -107,189 +104,205 @@ which are then used in rest of the module.
 
 =cut
 
-
-
 sub initialiseParameters {
-	
-	my $self = shift;
+
+	my $self   = shift;
 	my $params = shift;
-	
-	# set the hash to default values	
-	
+
+	# set the hash to default values
+
 	if ( !defined $params || !ref $params ) {
+
 		#return;
 		print "\nUndefined parameter reference";
 	}
 
-
 	my $file_path_name = $params->{'config'};
-	
+
 	my @source_list;
 	my @relation_list;
 	my @direction_list;
-	if (defined $params->{'sources'})
-	{
-		 @source_list   = @{$params->{'sources'}};
+	if ( defined $params->{'sources'} ) {
+		@source_list = @{ $params->{'sources'} };
 	}
-	if(defined $params->{'rels'} ){
-		 @relation_list = @{$params->{'rels'}};
+	if ( defined $params->{'rels'} ) {
+		@relation_list = @{ $params->{'rels'} };
 	}
-	if(defined $params->{'dirs'} ){
-		 @direction_list = @{$params->{'dirs'}};
+	if ( defined $params->{'dirs'} ) {
+		@direction_list = @{ $params->{'dirs'} };
 	}
-	
-		
+
+	my $r = 0;
+	my $d = 0;
 	#print "\n *****file path name: $file_path_name";
-	
-	
-	
-	if(defined $file_path_name && $file_path_name ne "") {
-		
+
+	if ( defined $file_path_name && $file_path_name ne "" ) {
+
 		my $pflag = 0;
 		my $dflag = 1;
-			# If user has provided a configuration file
+
+		# If user has provided a configuration file
 		open( CONFIG, $file_path_name )
 		  or die("Error: cannot open configuration file '$file_path_name'\n");
 
 		my @parameters = <CONFIG>;
-		
-		for my $p (0.. $#parameters){
-			
-		#	print "\n $param";
-		
-			
+
+		for my $p ( 0 .. $#parameters ) {
+
+			#	print "\n $param";
+
 			$parameters[$p] =~ /\s*(.*)\s*::\s*(.*?) (.*?)$/;
-			msg( "\n $1 \t $2 \t $3");
-			my $parameter_name = $1;
-			my $flag = $2;
+			msg("\n $1 \t $2 \t $3");
+			my $parameter_name  = $1;
+			my $flag            = $2;
 			my $parameter_value = $3;
 			my @parameter_array = ();
-			
-			$parameter_name =~ s/\s*//g;
+
+			$parameter_name  =~ s/\s*//g;
 			$parameter_value =~ s/\s*//g;
-			$flag =~ s/\s*//g;
+			$flag            =~ s/\s*//g;
+
 			#my @parameter_array
-			
-			
-			
-			if ($parameter_name && $flag && $parameter_value){
-				
-					
-				# If more than one sources/relations specified, then seperate by comma
-				if($parameter_value =~ /\,/){
-					
-				 @parameter_array = split("," , $parameter_value); 
+
+			if ( $parameter_name && $flag && $parameter_value ) {
+
+		  # If more than one sources/relations specified, then seperate by comma
+				if ( $parameter_value =~ /\,/ ) {
+
+					@parameter_array = split( ",", $parameter_value );
 				}
-				else{
-					
-				 $parameter_array[0] = $parameter_value;
-				 
+				else {
+
+					$parameter_array[0] = $parameter_value;
+
 				}
-				
+
 				$parameter_name =~ s/\s*//g;
+
 				#chop($parameter_name);
-			
-				if($parameter_name =~ /\bREL\b/)
-				{
+
+				if ( $parameter_name =~ /\bREL\b/ ) {
 					$pflag = 1;
 					$dflag = 0;
-				}
-				if($pflag == 1)
-				{
-					if ($parameter_name =~ /DIR/){
+					$r = $#parameter_array;
+									}
+				if ( $pflag == 1 ) {
+					if ( $parameter_name =~ /DIR/ ) {
 						$dflag = 1;
+					$d = $#parameter_array;	
 					}
 				}
-				if($flag =~/\binclude\b/)
-				{
+				if ( $flag =~ /\binclude\b/ ) {
+					
+
 					#print "\n including @parameter_array";
 					$self->{$parameter_name} = \@parameter_array;
-					msg("\n in hash $parameter_name: @{$self->{$parameter_name}}");
+					msg(
+"\n in hash $parameter_name: @{$self->{$parameter_name}}"
+					);
 				}
-				elsif ($flag =~ /\bexclude\b/)
-				{
+				elsif ( $flag =~ /\bexclude\b/ ) {
+
 					# Dont do anything for now
-					print "\n Invalid configurations: does not handle exclude yet\n";
-					print "\nPlease specify valid configuaration file by refering to the documentation\n";
+					print
+"\n Invalid configurations: does not handle exclude yet\n";
+					print
+"\nPlease specify valid configuaration file by refering to the documentation\n";
 					exit;
-					
+
 				}
-				else
-				{
-					print "\n Invalid configurations, may be forgot to have 'include' keyword\n";
-					print "\nPlease specify valid configuaration file by refering to the documentation\n";
+				else {
+					print
+"\n Invalid configurations, may be forgot to have 'include' keyword\n";
+					print
+"\nPlease specify valid configuaration file by refering to the documentation\n";
 					exit;
 				}
 			}
 			else
-			
+
 			{
 				print "\n Invalid configurations\n";
-				print "\nPlease specify valid configuaration file by refering to the documentation\n";
+				print
+"\nPlease specify valid configuaration file by refering to the documentation\n";
 				exit;
 			}
-			
+
 		}
-		if($dflag == 0)
-		{
-			print "\nIf relations are specified, it is necessay to specify directions for them";
-			print "\nPlease specify valid configuaration file by refering to the documentation\n";
+		
+		
+		if ( $dflag == 0 ) {
+			print
+"\nIf relations are specified, it is necessay to specify directions for them";
+			print
+"\nPlease specify valid configuaration file by refering to the documentation\n";
 			exit;
 		}
+		
+			
+		if($r != $d)
+			{
+				print
+"\nEach relation must have a corresponding direction in the configuaration";
+print
+"\nPlease specify valid configuaration file by refering to the documentation\n";
+				exit;
+				
+			}
+		
+		
+		
 	}
-	else
-	{
-		
+	else {
+
 		# If user has not provided a configuration file but has directly
-		# provided the configuration option in params hash		
-		
+		# provided the configuration option in params hash
+
 		# if no configuration file is specified
 		# if configuration parameters are set using hash as parameter
-		
-		if ( !defined $file_path_name && @source_list && @relation_list && @direction_list ) {
-		
-		$self->{"SAB"} = \@source_list;
-		$self->{"REL"} = \@relation_list;
-		$self->{"DIR"} = \@direction_list;
+
+		if (   !defined $file_path_name
+			&& @source_list
+			&& @relation_list
+			&& @direction_list )
+		{
+
+			$self->{"SAB"} = \@source_list;
+			$self->{"REL"} = \@relation_list;
+			$self->{"DIR"} = \@direction_list;
 		}
-		
-		else{
-			
-			if(@source_list){
+
+		else {
+
+			if (@source_list) {
 				$self->{"SAB"} = \@source_list;
 			}
-			if(@relation_list){
+			if (@relation_list) {
 				$self->{"REL"} = \@relation_list;
 			}
-			if(@direction_list){
+			if (@direction_list) {
 				$self->{"DIR"} = \@direction_list;
 			}
-			
-			
-			
+
 		}
+
 		#if(!defined $file_path_name && !@source_list && !@relation_list)
 		#{
 		#	# nothing is specified , then use default values
-			
+
 		#}
 	}
-	
-	
 
 }
 
 #-------------------------------PERLDOC STARTS HERE-------------------------------------------------------------
 
-
 =head1 SEE ALSO
 
 ValidateTerm.pm  GetUserData.pm   ConnectUMLS.pm  ws-getUMLSInfo.pl ws-getAllowablePath.pl
 
 =cut
 
-
-
 =head1 AUTHORS
 
 Mugdha Choudhari,             University of Minnesota Duluth
@@ -303,7 +316,7 @@ Ted Pedersen,                University of Minnesota Duluth
 
 =head1 COPYRIGHT
 
-Copyright (C) 2010, Mugdha Choudhari, Ted Pedersen
+Copyright (C) 2011, Mugdha Choudhari, Ted Pedersen
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -325,7 +338,4 @@ Boston, MA  02111-1307, USA.
 
 #---------------------------------PERLDOC ENDS HERE---------------------------------------------------------------
 
-
-
-
 1;    # End of WebService::UMLS::Similarity
